aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-ansi_a.h
diff options
context:
space:
mode:
authoretxrab <etxrab@f5534014-38df-0310-8fa8-9805f1628bb7>2006-11-22 06:39:24 +0000
committeretxrab <etxrab@f5534014-38df-0310-8fa8-9805f1628bb7>2006-11-22 06:39:24 +0000
commit3051db0aaf8b541d11fda19c5c02d1535172215b (patch)
treeb305c46903c9c11ae03ba6107293f1299512f8d4 /epan/dissectors/packet-ansi_a.h
parentafe7463bb94f39386792ed9d371530a29c632f67 (diff)
From Michael Lum
1) A small change in the number of teleservices recognized 2) Finally finished a lot of the changes for IOS 5 support. The attached files must be used together. Built in Windows XP Pro using Visual Studio C++ with the latest repository. packet-ansi_map.c.gz packet-ansi_a.gz This file contains both packet-ansi_a.c and packet-ansi_a.h changes. libwireshark.def.gz ansi_a_stat.c.gz git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@19955 f5534014-38df-0310-8fa8-9805f1628bb7
Diffstat (limited to 'epan/dissectors/packet-ansi_a.h')
-rw-r--r--epan/dissectors/packet-ansi_a.h33
1 files changed, 28 insertions, 5 deletions
diff --git a/epan/dissectors/packet-ansi_a.h b/epan/dissectors/packet-ansi_a.h
index 78c2cfd757..ae18cc9b55 100644
--- a/epan/dissectors/packet-ansi_a.h
+++ b/epan/dissectors/packet-ansi_a.h
@@ -32,26 +32,49 @@ typedef struct _ansi_a_tap_rec_t {
guint8 message_type;
} ansi_a_tap_rec_t;
+typedef struct ext_value_string_t
+{
+ guint32 value;
+ const gchar *strptr;
+ gint dec_index;
+}
+ext_value_string_t;
+
/*
* the following allows TAP code access to the messages
* without having to duplicate it. With MSVC and a
* libwireshark.dll, we need a special declaration.
*/
-WS_VAR_IMPORT const value_string ansi_a_ios401_bsmap_strings[];
-WS_VAR_IMPORT const value_string ansi_a_ios401_dtap_strings[];
+WS_VAR_IMPORT const ext_value_string_t *ansi_a_bsmap_strings;
+WS_VAR_IMPORT const ext_value_string_t *ansi_a_dtap_strings;
+WS_VAR_IMPORT const ext_value_string_t ansi_a_ios501_bsmap_strings[];
+WS_VAR_IMPORT const ext_value_string_t ansi_a_ios501_dtap_strings[];
+WS_VAR_IMPORT const ext_value_string_t ansi_a_ios401_bsmap_strings[];
+WS_VAR_IMPORT const ext_value_string_t ansi_a_ios401_dtap_strings[];
+
+#define A_VARIANT_IS634 4
+#define A_VARIANT_TSB80 5
+#define A_VARIANT_IS634A 6
+#define A_VARIANT_IOS2 7
+#define A_VARIANT_IOS3 8
+#define A_VARIANT_IOS401 9
+#define A_VARIANT_IOS501 10
+
+WS_VAR_IMPORT gint a_global_variant;
/*
* allows ANSI MAP to use this for IS-880 enhancements
+ * based on the 'ansi_a_ios401_elem_1_strings/ansi_a_ios501_elem_1_strings'
*/
-extern const value_string ansi_a_ios401_elem_1_strings[];
+WS_VAR_IMPORT const ext_value_string_t *ansi_a_elem_1_strings;
/*
* maximum number of strings that are allowed
* 255 because IEI are 1 octet in length
*
* this define is required by dissectors that need to
* size based on the 'ansi_a_ios401_elem_1_strings'
* array
*/
-#define ANSI_A_MAX_NUM_IOS401_ELEM_1_STRINGS 255
+#define ANSI_A_MAX_NUM_IOS_ELEM_1_STRINGS 255
@@ -32,26 +32,49 @@ typedef struct _ansi_a_tap_rec_t {
*
* this define is required by dissectors that need to
- * size based on the 'ansi_a_ios401_elem_1_strings'
+ * size based on the 'ansi_a_elem_1_strings'
* array
*/